@@ -18,14 +18,31 @@ case "$1" in
         PID=`cat /var/run/snarecore.pid 2>/dev/null`
         if [ ! -z "$PID" ] ;  then
 		echo "Snare already running. Please stop Snare first."
-		exit 1;
+		exit 1
 	fi
-        if [ -f /etc/security/snarecore -a -f /etc/security/audit_control ] ; then
+
+	/usr/bin/id | /usr/bin/grep '^uid=0' > /dev/null
+	if [ $? -ne 0 ]; then
+		echo "Sorry, you need to be root to start snare."
+		exit 1
+	fi
+
+	# Audit public files.
+	auditconfig -setpolicy +public >/dev/null 2>&1
+
+        if [ -f /usr/bin/snarecore -a -f /etc/security/audit_control ] ; then
                 echo "Snare starting."
-		/etc/security/snarecore
+		/usr/bin/snarecore
         fi
+	exit 0
         ;;
 'stop')
+	/usr/bin/id | grep '^uid=0' > /dev/null
+	if [ $? -ne 0 ]; then
+		echo "Sorry, you need to be root to start snare."
+		exit 1
+	fi
+
 	# Turn off auditing. This will also kill SNARE nicely.
 	auditconfig -setcond noaudit
 	sleep 1
@@ -33,30 +50,38 @@ case "$1" in
        	if [ ! -z "$PID" ] ;  then
 		kill ${PID}
 	fi
-	rm /var/run/snarecore.pid 2>/dev/null
+	rm -f /var/run/snarecore.pid 2>/dev/null
 	sleep 1
 
 	# Just in case:
 	# Kill all snare processes, sorted on parent process ID
 	# This way snare with ppid of 1 gets killed first
-        /usr/bin/ps -e -u 0 -o "pid,ppid,comm"|/usr/bin/fgrep snarecor|/usr/bin/egrep -v fgrep|/usr/bin/sort -n +1|/usr/bin/awk '{print $1}' |
+        /usr/bin/ps -e -u 0 -o "pid,ppid,comm"|/usr/bin/egrep "(snarecor|praudit)" |/usr/bin/egrep -v egrep|/usr/bin/sort -n +1|/usr/bin/awk '{print $1}' |
 		while read pid ppid command; do
 			if [ ! -z "$pid" ] ; then
 				echo "Cleaning up stale snare process $pid"
 				kill ${pid} 1>/dev/null 2>&1
 			fi
 		done
-	exit 1;
+	exit 0
         ;;
 'restart')
         if [ -f /etc/init.d/snare ] ; then
 		/etc/init.d/snare stop
+		RC=$?
+		if [ $RC -gt 0 ]; then
+			exit $RC
+		fi
 		/etc/init.d/snare start
+		RC=$?
+		if [ $RC -gt 0 ]; then
+			exit $RC
+		fi
 	fi
 	;;
 	
 *)
-        echo "Usage: /etc/init.d/snare { start | stop | restart }"
+        echo 'Usage: /etc/init.d/snare { start | stop | restart }'
         ;;
 esac
 
