@@ -97,9 +97,9 @@ restore_key_files()
    fi 
 
    echo "Removing snarecore binary..."
-   if [ -f /etc/security/snarecore ]
+   if [ -f /usr/bin/snarecore ]
    then
-	rm /etc/security/snarecore 2>/dev/null
+	rm /usr/bin/snarecore 2>/dev/null
         echo "Done."
    fi
 
